package entity

import (
	"time"

	"github.com/photoprism/photoprism/pkg/fs"
	"github.com/photoprism/photoprism/pkg/media"
)

type FileMap map[string]File

func (m FileMap) Get(name string) File {
	if result, ok := m[name]; ok {
		return result
	}

	return File{FileName: name}
}

func (m FileMap) Pointer(name string) *File {
	if result, ok := m[name]; ok {
		return &result
	}

	return &File{FileName: name}
}

var FileFixtures = FileMap{
	"exampleFileName.jpg": {
		ID:              1000000,
		Photo:           PhotoFixtures.Pointer("19800101_000002_D640C559"),
		PhotoID:         PhotoFixtures.Pointer("19800101_000002_D640C559").ID,
		PhotoUID:        PhotoFixtures.Pointer("19800101_000002_D640C559").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96087uy",
		FileUID:         "ft8es39w45bnlqdw",
		FileName:        "2790/07/27900704_070228_D6D51B6C.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "Vacation/exampleFileNameOriginal.jpg",
		FileHash:        "2cad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        4278906,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       3648,
		FileHeight:      2736,
		FileOrientation: 0,
		FileProjection:  "equirectangular",
		FileAspectRatio: 1.33333,
		FileMainColor:   "green",
		FileColors:      "929299991",
		FileLuminance:   "8836BD496",
		FileDiff:        968,
		FileChroma:      25,
		FileError:       "",
		ModTime:         time.Date(2020, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		Share: []FileShare{
			FileShareFixtures.Get("FileShare1", 0, 0, ""),
			FileShareFixtures.Get("FileShare2", 0, 0, ""),
		},
		Sync:      []FileSync{},
		CreatedAt: time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn: 414671279,
		UpdatedAt: time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn: 847648638,
		DeletedAt: nil,
	},
	"exampleDNGFile.dng": {
		ID:              1000001,
		Photo:           PhotoFixtures.Pointer("Photo01"),
		PhotoID:         PhotoFixtures.Pointer("Photo01").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo01").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aa",
		FileUID:         "ft9es39w45bnlqdw",
		FileName:        "2790/02/Photo01.dng",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "3cad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        661858,
		FileCodec:       "jpeg",
		FileType:        "raw",
		MediaType:       string(media.Raw),
		FileMime:        "image/DNG",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "gold",
		FileColors:      "5552E2222",
		FileLuminance:   "444428399",
		FileDiff:        747,
		FileChroma:      12,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       414671279,
		UpdatedAt:       time.Date(2020, 3, 28, 14, 6, 0, 0, time.UTC),
		UpdatedIn:       847648638,
		DeletedAt:       nil,
	},
	"exampleXmpFile.xmp": {
		ID:              1000002,
		Photo:           PhotoFixtures.Pointer("Photo01"),
		PhotoID:         PhotoFixtures.Pointer("Photo01").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo01").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ab",
		FileUID:         "ft1es39w45bnlqdw",
		FileName:        "2790/02/Photo01.xmp",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "ocad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        858,
		FileCodec:       "",
		FileType:        "xmp",
		MediaType:       string(media.Sidecar),
		FileMime:        "",
		FilePrimary:     false,
		FileSidecar:     true,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       0,
		FileHeight:      0,
		FileOrientation: 0,
		FileProjection:  "",
		FileAspectRatio: 1,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 3, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 3, 28, 14, 6, 0, 0, time.UTC),
		UpdatedIn:       9537701,
		DeletedAt:       nil,
	},
	"bridge.jpg": {
		ID:              1000003,
		Photo:           PhotoFixtures.Pointer("Photo04"),
		PhotoID:         PhotoFixtures.Pointer("Photo04").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo04").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ac",
		FileUID:         "ft2es39w45bnlqdw",
		FileName:        "Germany/bridge.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        961858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       12361490,
		DeletedAt:       nil,
	},
	"reunion.jpg": {
		ID:              1000004,
		Photo:           PhotoFixtures.Pointer("Photo05"),
		PhotoID:         PhotoFixtures.Pointer("Photo05").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo05").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft3es39w45bnlqdw",
		FileName:        "2015/11/20151101_000000_51C501B5.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "2015/11/reunion.jpg",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd818",
		FileSize:        81858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      4,
		FileError:       "Error",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       12361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361491,
		DeletedAt:       nil,
	},
	"Quality1FavoriteTrue.jpg": {
		ID:              1000005,
		Photo:           PhotoFixtures.Pointer("Photo17"),
		PhotoID:         PhotoFixtures.Pointer("Photo17").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo17").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ad",
		FileUID:         "ft4es39w45bnlqdw",
		FileName:        "1990/04/Quality1FavoriteTrue.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd819",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      26,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361498,
		DeletedAt:       nil,
	},
	"missing.jpg": {
		ID:              1000006,
		Photo:           PhotoFixtures.Pointer("Photo15"),
		PhotoID:         PhotoFixtures.Pointer("Photo15").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo15").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ae",
		FileUID:         "ft5es39w45bnlqdw",
		FileName:        "1990/missing.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd819",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     true,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "blue",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      26,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       2361491,
		DeletedAt:       nil,
	},
	"Photo18.jpg": {
		ID:              1000007,
		Photo:           nil, // no pointer here because related photo is archived
		PhotoID:         1000018,
		PhotoUID:        "pt9jtdre2lvl0y25",
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080af",
		FileUID:         "ft6es39w45bnlqdw",
		FileName:        "Archived/Photo18.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd820",
		FileSize:        500,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       2361491,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       8361491,
		DeletedAt:       nil,
	},
	"Video.mp4": {
		ID:              1000008,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ag",
		FileUID:         "ft71s39w45bnlqdw",
		FileName:        "Holiday/Video.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd831",
		FileSize:        7799202,
		FileCodec:       "avc1",
		FileType:        "mp4",
		MediaType:       string(media.Video),
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Video.jpg": {
		ID:              1000014,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "",
		FileUID:         "fikjs39w45bnlqdw",
		FileName:        "Holiday/Video.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "abgt9168fa6acc5c5c2965ddf6ec465ca42fd831",
		FileSize:        7799202,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"VideoWithError.mp4": {
		ID:              1000009,
		Photo:           PhotoFixtures.Pointer("Photo10"),
		PhotoID:         PhotoFixtures.Pointer("Photo10").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo10").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ah",
		FileUID:         "ft72s39w45bnlqdw",
		FileName:        "Holiday/VideoError.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "acad9168fa6acc5c5c2965ddf6ec465ca42fd832",
		FileSize:        500,
		FileCodec:       "avc1",
		FileType:        "mp4",
		MediaType:       string(media.Video),
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "green",
		FileColors:      "266111000",
		FileLuminance:   "DC42844C8",
		FileDiff:        800,
		FileChroma:      0,
		FileError:       "Error",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge1.jpg": {
		ID:              1000010,
		Photo:           PhotoFixtures.Pointer("Photo02"),
		PhotoID:         PhotoFixtures.Pointer("Photo02").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo02").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ai",
		FileUID:         "ft2es39q45bnlqd0",
		FileName:        "London/bridge1.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965ddf6ec465ca42fd828",
		FileSize:        961851,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge2.jpg": {
		ID:              1000011,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         PhotoFixtures.Pointer("Photo03").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aj",
		FileUID:         "ft2es49w15bnlqdw",
		FileName:        "1990/04/bridge2.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd818",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge3.jpg": {
		ID:              1000012,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         PhotoFixtures.Pointer("Photo03").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080aj",
		FileUID:         "ft2es49whhbnlqdn",
		FileName:        "London/bridge3.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5ba965adf6ec465ca42fd818",
		FileSize:        921851,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"bridge2.mp4": {
		ID:              1000013,
		Photo:           PhotoFixtures.Pointer("Photo03"),
		PhotoID:         PhotoFixtures.Pointer("Photo03").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo03").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080al",
		FileUID:         "ft2es49whhbnlqdy",
		FileName:        "1990/04/bridge2.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5ba965adf6ec465ca42fd819",
		FileSize:        921851,
		FileCodec:       "avc1",
		FileType:        "mp4",
		MediaType:       string(media.Video),
		FileMime:        "image/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    17000000000,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo19.jpg": {
		ID:              1000019,
		Photo:           PhotoFixtures.Pointer("Photo19"),
		PhotoID:         PhotoFixtures.Pointer("Photo19").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo19").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080am",
		FileUID:         "ft2es49qhhinlqdn",
		FileName:        "1990/04/Photo19.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd811",
		FileSize:        921831,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo25.jpg": {
		ID:              1000020,
		Photo:           PhotoFixtures.Pointer("Photo25"),
		PhotoID:         PhotoFixtures.Pointer("Photo25").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo25").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080an",
		FileUID:         "ft2es49qhhinlplk",
		FileName:        "2007/12/PhotoWithEditedAt.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd887",
		FileSize:        921831,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       2200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2007, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2007, 3, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo25_2.jpg": {
		ID:              1000021,
		Photo:           PhotoFixtures.Pointer("Photo25"),
		PhotoID:         PhotoFixtures.Pointer("Photo25").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo25").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec96080ao",
		FileUID:         "ft2es49qhhinlpld",
		FileName:        "2007/12/PhotoWithEditedAt_2.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd895",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       2200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo27.jpg": {
		ID:              1000022,
		Photo:           PhotoFixtures.Pointer("Photo27"),
		PhotoID:         PhotoFixtures.Pointer("Photo27").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo27").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlple",
		FileName:        "2000/12/PhotoToBeBatchApproved2.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd896",
		FileSize:        900,
		FileCodec:       "",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo27.mp4": {
		ID:              1000023,
		Photo:           PhotoFixtures.Pointer("Photo27"),
		PhotoID:         PhotoFixtures.Pointer("Photo27").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo27").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplf",
		FileName:        "2000/12/PhotoToBeBatchApproved2.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd897",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		MediaType:       string(media.Video),
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    1000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2008, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2011, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo24.jpg": {
		ID:              1000024,
		Photo:           PhotoFixtures.Pointer("Photo24"),
		PhotoID:         PhotoFixtures.Pointer("Photo24").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo24").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplg",
		FileName:        "2020/vacation/PhotoMerge2.JPG",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd898",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo24.cr2": {
		ID:              1000025,
		Photo:           PhotoFixtures.Pointer("Photo24"),
		PhotoID:         PhotoFixtures.Pointer("Photo24").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo24").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplh",
		FileName:        "2020/vacation/PhotoMerge2.CR2",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd899",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "raw",
		MediaType:       string(media.Raw),
		FileMime:        "image/x-canon-cr2",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo23.jpg": {
		ID:              1000026,
		Photo:           PhotoFixtures.Pointer("Photo23"),
		PhotoID:         PhotoFixtures.Pointer("Photo23").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo23").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpli",
		FileName:        "2020/vacation/PhotoMerge.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd911",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo22.jpg": {
		ID:              1000027,
		Photo:           PhotoFixtures.Pointer("Photo22"),
		PhotoID:         PhotoFixtures.Pointer("Photo22").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo22").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplj",
		FileName:        "Mexico-With-Family/Photo22.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd912",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo22-stack.jpg": {
		ID:              1000028,
		Photo:           PhotoFixtures.Pointer("Photo22"),
		PhotoID:         PhotoFixtures.Pointer("Photo22").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo22").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlolk",
		FileName:        "Mexico-Favorites/IMG-1234.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd913",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2010, 1, 1, 8, 5, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2010, 1, 1, 8, 5, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo21.mp4.jpg": {
		ID:              1000029,
		Photo:           PhotoFixtures.Pointer("Photo21"),
		PhotoID:         PhotoFixtures.Pointer("Photo21").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo21").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpll",
		FileName:        "2018/01/20180101_130410_418COOO0.mp4.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd914",
		FileSize:        900,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo21.mp4": {
		ID:              1000030,
		Photo:           PhotoFixtures.Pointer("Photo21"),
		PhotoID:         PhotoFixtures.Pointer("Photo21").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo21").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplm",
		FileName:        "2018/01/20180101_130410_418COOO0.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "my-videos/IMG_88888.MP4",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd915",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    115000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"FileWithoutPhoto.mp4": {
		ID:              1000031,
		PhotoUID:        "",
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpln",
		FileName:        "FileWithoutPhoto.mp4",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd916",
		FileSize:        900,
		FileCodec:       "avc1",
		FileType:        "mp4",
		FileMime:        "video/mp4",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       true,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    115000000000,
		FileWidth:       200,
		FileHeight:      1100,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 2,
		FileMainColor:   "red",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2020, 12, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo06.png": {
		ID:              1000032,
		Photo:           PhotoFixtures.Pointer("Photo06"),
		PhotoID:         PhotoFixtures.Pointer("Photo06").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo06").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplo",
		FileName:        "2016/11/Photo06.png",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd917",
		FileSize:        7799202,
		FileCodec:       "deflate/inflate",
		FileType:        "png",
		FileMime:        "image/png",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo06.jpg": {
		ID:              1000033,
		Photo:           PhotoFixtures.Pointer("Photo06"),
		PhotoID:         PhotoFixtures.Pointer("Photo06").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo06").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplp",
		FileName:        "2016/11/Photo06.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd918",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "white",
		FileColors:      "44444E449",
		FileLuminance:   "FFFFF2FF9",
		FileDiff:        1022,
		FileChroma:      8,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo07.heic": {
		ID:              1000034,
		Photo:           PhotoFixtures.Pointer("Photo07"),
		PhotoID:         PhotoFixtures.Pointer("Photo07").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo07").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplq",
		FileName:        "2016/11/Photo07.heic",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd918",
		FileSize:        199202,
		FileCodec:       "heic",
		FileType:        "heif",
		FileMime:        "image/heif",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "",
		FileColors:      "",
		FileLuminance:   "",
		FileDiff:        0,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo07.heic.jpg": {
		ID:              1000035,
		Photo:           PhotoFixtures.Pointer("Photo07"),
		PhotoID:         PhotoFixtures.Pointer("Photo07").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo07").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplr",
		FileName:        "2016/11/Photo07.heic.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd920",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "white",
		FileColors:      "44444E449",
		FileLuminance:   "FFFFF2FF9",
		FileDiff:        1022,
		FileChroma:      8,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo08.jpg": {
		ID:              1000036,
		Photo:           PhotoFixtures.Pointer("Photo08"),
		PhotoID:         PhotoFixtures.Pointer("Photo08").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo08").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlpls",
		FileName:        "2016/11/Photo08.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd921",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo09.jpg": {
		ID:              1000036,
		Photo:           PhotoFixtures.Pointer("Photo09"),
		PhotoID:         PhotoFixtures.Pointer("Photo09").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo09").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplt",
		FileName:        "2016/11/Photo09.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd922",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo09(L).jpg": {
		ID:              1000037,
		Photo:           PhotoFixtures.Pointer("Photo09"),
		PhotoID:         PhotoFixtures.Pointer("Photo09").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo09").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplu",
		FileName:        "2016/11/Photo09(L).jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd923",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo11.jpg": {
		ID:              1000038,
		Photo:           PhotoFixtures.Pointer("Photo11"),
		PhotoID:         PhotoFixtures.Pointer("Photo11").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo11").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplv",
		FileName:        "2016/12/Photo11.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd924",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo12.jpg": {
		ID:              1000039,
		Photo:           PhotoFixtures.Pointer("Photo12"),
		PhotoID:         PhotoFixtures.Pointer("Photo12").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo12").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplx",
		FileName:        "2016/01/Photo12.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd925",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo13.jpg": {
		ID:              1000040,
		Photo:           PhotoFixtures.Pointer("Photo13"),
		PhotoID:         PhotoFixtures.Pointer("Photo13").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo13").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlply",
		FileName:        "2016/06/Photo13.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd926",
		FileSize:        199202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    false,
		FileDuration:    0,
		FileWidth:       16000,
		FileHeight:      16000,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 1,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        734,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo14.jpg": {
		ID:              1000041,
		Photo:           PhotoFixtures.Pointer("Photo14"),
		PhotoID:         PhotoFixtures.Pointer("Photo14").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo14").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlplz",
		FileName:        "2018/11/Photo14.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd927",
		FileSize:        8202,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        534,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo16.jpg": {
		ID:              1000042,
		Photo:           PhotoFixtures.Pointer("Photo16"),
		PhotoID:         PhotoFixtures.Pointer("Photo16").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo16").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlrta",
		FileName:        "1990/Photo16.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd928",
		FileSize:        8402,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        234,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"Photo20.jpg": {
		ID:              1000043,
		Photo:           PhotoFixtures.Pointer("Photo20"),
		PhotoID:         PhotoFixtures.Pointer("Photo20").ID,
		PhotoUID:        PhotoFixtures.Pointer("Photo20").PhotoUID,
		InstanceID:      "",
		FileUID:         "ft2es49qhhinlrtb",
		FileName:        "1990/04/Photo20.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9a68fa6acc5c5ba965adf6ec465ca42fd929",
		FileSize:        6402,
		FileCodec:       "",
		FileType:        "jpg",
		FileMime:        "image/jpeg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       640,
		FileHeight:      1136,
		FileOrientation: 1,
		FileProjection:  "",
		FileAspectRatio: 0.56,
		FileMainColor:   "grey",
		FileColors:      "141101110",
		FileLuminance:   "BD9A22751",
		FileDiff:        9934,
		FileChroma:      0,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2019, 1, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       9359616,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"%photo28.jpg": {
		ID:              1000044,
		Photo:           PhotoFixtures.Pointer("%photo28"),
		PhotoID:         PhotoFixtures.Pointer("%photo28").ID,
		PhotoUID:        PhotoFixtures.Pointer("%photo28").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608331",
		FileUID:         "ft2es49w15bnl331",
		FileName:        "%abc/%folderx/%photo28.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd331",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo29%.jpg": {
		ID:              1000045,
		Photo:           PhotoFixtures.Pointer("photo29%"),
		PhotoID:         PhotoFixtures.Pointer("photo29%").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo29%").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608332",
		FileUID:         "ft2es49w15bnl332",
		FileName:        "abc%/folde%/photo29%.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd332",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo%30.jpg": {
		ID:              1000046,
		Photo:           PhotoFixtures.Pointer("photo%30"),
		PhotoID:         PhotoFixtures.Pointer("photo%30").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo%30").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608333",
		FileUID:         "ft2es49w15bnl333",
		FileName:        "ab%c/fol%de/photo%30.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd333",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"&photo31.jpg": {
		ID:              1000047,
		Photo:           PhotoFixtures.Pointer("&photo31"),
		PhotoID:         PhotoFixtures.Pointer("&photo31").ID,
		PhotoUID:        PhotoFixtures.Pointer("&photo31").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608334",
		FileUID:         "ft2es49w15bnl334",
		FileName:        "&abc/&folde/&photo31.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd334",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo&32.jpg": {
		ID:              1000048,
		Photo:           PhotoFixtures.Pointer("photo&32"),
		PhotoID:         PhotoFixtures.Pointer("photo&32").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo&32").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608335",
		FileUID:         "ft2es49w15bnl335",
		FileName:        "tes&r/lo&c/photo&32.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd335",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo33&.jpg": {
		ID:              1000049,
		Photo:           PhotoFixtures.Pointer("photo33&"),
		PhotoID:         PhotoFixtures.Pointer("photo33&").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo33&").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608336",
		FileUID:         "ft2es49w15bnl336",
		FileName:        "tes&r/lo&c/photo33&.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd336",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"'photo34.jpg": {
		ID:              1000050,
		Photo:           PhotoFixtures.Pointer("'photo34"),
		PhotoID:         PhotoFixtures.Pointer("'photo34").ID,
		PhotoUID:        PhotoFixtures.Pointer("'photo34").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608337",
		FileUID:         "ft2es49w15bnl337",
		FileName:        "'2020/'vacation/'photo34.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd337",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo'35.jpg": {
		ID:              1000051,
		Photo:           PhotoFixtures.Pointer("photo'35"),
		PhotoID:         PhotoFixtures.Pointer("photo'35").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo'35").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608338",
		FileUID:         "ft2es49w15bnl338",
		FileName:        "20'20/vacat'ion/photo'35.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd338",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo36'.jpg": {
		ID:              1000052,
		Photo:           PhotoFixtures.Pointer("photo36'"),
		PhotoID:         PhotoFixtures.Pointer("photo36'").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo36'").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608339",
		FileUID:         "ft2es49w15bnl339",
		FileName:        "2020'/vacation'/photo36'.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd339",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"*photo37.jpg": {
		ID:              1000053,
		Photo:           PhotoFixtures.Pointer("*photo37"),
		PhotoID:         PhotoFixtures.Pointer("*photo37").ID,
		PhotoUID:        PhotoFixtures.Pointer("*photo37").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608340",
		FileUID:         "ft2es49w15bnl340",
		FileName:        "*2020/*vacation/*photo37.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd340",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo*38.jpg": {
		ID:              1000054,
		Photo:           PhotoFixtures.Pointer("photo*38"),
		PhotoID:         PhotoFixtures.Pointer("photo*38").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo*38").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608341",
		FileUID:         "ft2es49w15bnl341",
		FileName:        "202*3/vac*ation/photo*38.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd341",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo39*.jpg": {
		ID:              1000055,
		Photo:           PhotoFixtures.Pointer("photo39*"),
		PhotoID:         PhotoFixtures.Pointer("photo39*").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo39*").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608342",
		FileUID:         "ft2es49w15bnl342",
		FileName:        "2023*/vacatio*/photo39*.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd342",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"|photo40.jpg": {
		ID:              1000056,
		Photo:           PhotoFixtures.Pointer("|photo40"),
		PhotoID:         PhotoFixtures.Pointer("|photo40").ID,
		PhotoUID:        PhotoFixtures.Pointer("|photo40").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608343",
		FileUID:         "ft2es49w15bnl343",
		FileName:        "|202/|vacation/|photo40.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd343",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo|41.jpg": {
		ID:              1000057,
		Photo:           PhotoFixtures.Pointer("photo|41"),
		PhotoID:         PhotoFixtures.Pointer("photo|41").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo|41").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608344",
		FileUID:         "ft2es49w15bnl344",
		FileName:        "20|22/vacat|ion/photo|41.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd344",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo42|.jpg": {
		ID:              1000058,
		Photo:           PhotoFixtures.Pointer("photo42|"),
		PhotoID:         PhotoFixtures.Pointer("photo42|").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo42|").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608345",
		FileUID:         "ft2es49w15bnl345",
		FileName:        "2022|/vacation|/photo42|.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3445",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"43photo.jpg": {
		ID:              1000059,
		Photo:           PhotoFixtures.Pointer("43photo"),
		PhotoID:         PhotoFixtures.Pointer("43photo").ID,
		PhotoUID:        PhotoFixtures.Pointer("43photo").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608346",
		FileUID:         "ft2es49w15bnl346",
		FileName:        "2000/holiday/43photo.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3446",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"pho44to.jpg": {
		ID:              1000060,
		Photo:           PhotoFixtures.Pointer("pho44to"),
		PhotoID:         PhotoFixtures.Pointer("pho44to").ID,
		PhotoUID:        PhotoFixtures.Pointer("pho44to").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608347",
		FileUID:         "ft2es49w15bnl347",
		FileName:        "2000/02/pho44to.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3447",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo45.jpg": {
		ID:              1000061,
		Photo:           PhotoFixtures.Pointer("photo45"),
		PhotoID:         PhotoFixtures.Pointer("photo45").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo45").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608348",
		FileUID:         "ft2es49w15bnl348",
		FileName:        "2000/02/photo45.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3448",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"\"photo46.jpg": {
		ID:              1000062,
		Photo:           PhotoFixtures.Pointer("\"photo46"),
		PhotoID:         PhotoFixtures.Pointer("\"photo46").ID,
		PhotoUID:        PhotoFixtures.Pointer("\"photo46").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608349",
		FileUID:         "ft2es49w15bnl349",
		FileName:        "\"2000/\"02/\"photo46.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3449",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo\"47.jpg": {
		ID:              1000063,
		Photo:           PhotoFixtures.Pointer("photo\"47"),
		PhotoID:         PhotoFixtures.Pointer("photo\"47").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo\"47").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608350",
		FileUID:         "ft2es49w15bnl350",
		FileName:        "20\"00/0\"2/photo\"47.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3450",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo48\".jpg": {
		ID:              1000064,
		Photo:           PhotoFixtures.Pointer("photo48\""),
		PhotoID:         PhotoFixtures.Pointer("photo48\"").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo48\"").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608351",
		FileUID:         "ft2es49w15bnl351",
		FileName:        "2000\"/02\"/photo48\".jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3451",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        string(fs.ImageJPEG),
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	" photo49.jpg": {
		ID:              1000065,
		Photo:           PhotoFixtures.Pointer(" photo49"),
		PhotoID:         PhotoFixtures.Pointer(" photo49").ID,
		PhotoUID:        PhotoFixtures.Pointer(" photo49").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608352",
		FileUID:         "ft2es49w15bnl352",
		FileName:        " 2000/ 02/ photo49.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3452",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo 50.jpg": {
		ID:              1000066,
		Photo:           PhotoFixtures.Pointer("photo 50"),
		PhotoID:         PhotoFixtures.Pointer("photo 50").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo 50").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608353",
		FileUID:         "ft2es49w15bnl353",
		FileName:        "20 00/ 0 2/photo 50.jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3453",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		MediaType:       string(media.Image),
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo51 .jpg": {
		ID:              1000067,
		Photo:           PhotoFixtures.Pointer("photo51 "),
		PhotoID:         PhotoFixtures.Pointer("photo51 ").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo51 ").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608354",
		FileUID:         "ft2es49w15bnl354",
		FileName:        "2000 /02 /photo51 .jpg",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3454",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo52.gif.jpg": {
		ID:              1000068,
		Photo:           PhotoFixtures.Pointer("photo52"),
		PhotoID:         PhotoFixtures.Pointer("photo52").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo52").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608355",
		FileUID:         "ft2es49w15bnl355",
		FileName:        "2020/GIF/photo52.gif.jpg",
		FileRoot:        RootSidecar,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3455",
		FileSize:        921858,
		FileCodec:       "jpeg",
		FileType:        "jpg",
		FileMime:        "image/jpg",
		FilePrimary:     true,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    0,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
	"photo52.gif": {
		ID:              1000069,
		Photo:           PhotoFixtures.Pointer("photo52"),
		PhotoID:         PhotoFixtures.Pointer("photo52").ID,
		PhotoUID:        PhotoFixtures.Pointer("photo52").PhotoUID,
		InstanceID:      "a698ac56-6e7e-42b9-9c3e-a79ec9608356",
		FileUID:         "ft2es49w15bnl356",
		FileName:        "2020/GIF/photo52.gif",
		FileRoot:        RootOriginals,
		OriginalName:    "",
		FileHash:        "pcad9168fa6acc5c5c2965adf6ec465ca42fd3456",
		FileSize:        407701,
		FileCodec:       "gif",
		FileType:        "gif",
		FileMime:        "image/gif",
		FilePrimary:     false,
		FileSidecar:     false,
		FileVideo:       false,
		FileMissing:     false,
		FilePortrait:    true,
		FileDuration:    15000000000,
		FileFPS:         0.4666666666666667,
		FileFrames:      7,
		FileWidth:       1200,
		FileHeight:      1600,
		FileOrientation: 6,
		FileProjection:  "",
		FileAspectRatio: 0.75,
		FileMainColor:   "magenta",
		FileColors:      "225221C1E",
		FileLuminance:   "DC42844C8",
		FileDiff:        986,
		FileChroma:      32,
		FileError:       "",
		Share:           []FileShare{},
		Sync:            []FileSync{},
		ModTime:         time.Date(2017, 2, 6, 2, 6, 51, 0, time.UTC).Unix(),
		CreatedAt:       time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		CreatedIn:       935962,
		UpdatedAt:       time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedIn:       935962,
		DeletedAt:       nil,
	},
}

var FileFixturesExampleJPG = FileFixtures["exampleFileName.jpg"]
var FileFixturesExampleXMP = FileFixtures["exampleXmpFile.xmp"]
var FileFixturesExampleBridge = FileFixtures["bridge.jpg"]
var FileFixturesExampleBridgeVideo = FileFixtures["bridge2.mp4"]

// CreateFileFixtures inserts known entities into the database for testing.
func CreateFileFixtures() {
	for _, entity := range FileFixtures {
		Db().Create(&entity)
	}
}
